California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance Activity Propositions & Ballot Measures
Election Cycle: 2021 through 2022 Historical 2019 through 2020 2017 through 2018 2015 through 2016 2013 through 2014 2011 through 2012 2009 through 2010 2007 through 2008 2005 through 2006 2003 through 2004 2001 through 2002 1999 through 2000
All of the campaign committees that have organized to support or oppose propositions and ballot measures on California's statewide ballot are available here. Click below on the proposition or ballot measure to learn who is involved in the campaign to win your vote on Election Day.
Prior Elections
NOVEMBER 6, 2018, GENERAL
11 Measures
PROPOSITION 001 - AUTHORIZES BONDS TO FUND SPECIFIED HOUSING ASSISTANCE PROGRAMS. LEGISLATIVE STATUTE.
PROPOSITION 002 - AUTHORIZES BONDS TO FUND EXISTING HOUSING PROGRAM FOR INDIVIDUALS WITH MENTAL ILLNESS. LEGISLATIVE STATUTE.
PROPOSITION 003 - AUTHORIZES BONDS TO FUND PROJECTS FOR WATER SUPPLY AND QUALITY, WATERSHED, FISH, WILDLIFE, WATER CONVEYANCE, AND GROUNDWATER SUSTAINABILITY AND STORAGE. INITIATIVE STATUTE.
PROPOSITION 004 - AUTHORIZES BONDS FUNDING CONSTRUCTION AT HOSPITALS PROVIDING CHILDREN’S HEALTH CARE. INITIATIVE STATUTE.
PROPOSITION 005 - CHANGES REQUIREMENTS FOR CERTAIN PROPERTY OWNERS TO TRANSFER THEIR PROPERTY TAX BASE TO REPLACEMENT PROPERTY. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE.
PROPOSITION 006 - ELIMINATES CERTAIN ROAD REPAIR AND TRANSPORTATION FUNDING. REQUIRES CERTAIN FUEL TAXES AND VEHICLE FEES BE APPROVED BY THE ELECTORATE. INITIATIVE CONSTITUTIONAL AMENDMENT.
PROPOSITION 007 - CONFORMS CALIFORNIA DAYLIGHT SAVING TIME TO FEDERAL LAW. ALLOWS LEGISLATURE TO CHANGE DAYLIGHT SAVING TIME PERIOD. LEGISLATIVE STATUTE.
PROPOSITION 008 - REGULATES AMOUNTS OUTPATIENT KIDNEY DIALYSIS CLINICS CHARGE FOR DIALYSIS TREATMENT. INITIATIVE STATUTE.
PROPOSITION 010 - EXPANDS LOCAL GOVERNMENTS’ AUTHORITY TO ENACT RENT CONTROL ON RESIDENTIAL PROPERTY. INITIATIVE STATUTE.
PROPOSITION 011 - REQUIRES PRIVATE-SECTOR EMERGENCY AMBULANCE EMPLOYEES TO REMAIN ON-CALL DURING WORK BREAKS. ELIMINATES CERTAIN EMPLOYER LIABILITY. INITIATIVE STATUTE.
PROPOSITION 012 - ESTABLISHES NEW STANDARDS FOR CONFINEMENT OF SPECIFIED FARM ANIMALS; BANS SALE OF NONCOMPLYING PRODUCTS. INITIATIVE STATUTE.
JUNE 5, 2018, PRIMARY
5 Measures
PROPOSITION 068 - AUTHORIZES BONDS FUNDING PARKS, NATURAL RESOURCES PROTECTION, CLIMATE ADAPTATION, WATER QUALITY AND SUPPLY, AND FLOOD PROTECTION.
PROPOSITION 069 - REQUIRES THAT CERTAIN NEW TRANSPORTATION REVENUES BE USED FOR TRANSPORTATION PURPOSES. LEGISLATIVE CONSTITUTIONAL AMENDMENT.
PROPOSITION 070 - REQUIRES LEGISLATIVE SUPERMAJORITY VOTE APPROVING USE OF CAP-AND-TRADE RESERVE FUND. LEGISLATIVE CONSTITUTIONAL AMENDMENT.
PROPOSITION 071 - SETS EFFECTIVE DATE FOR BALLOT MEASURES. LEGISLATIVE CONSTITUTIONAL AMENDMENT.
PROPOSITION 072 - PERMITS LEGISLATURE TO EXCLUDE NEWLY CONSTRUCTED RAIN-CAPTURE SYSTEMS FROM PROPERTY-TAX REASSESSMENT REQUIREMENT. LEGISLATIVE CONSTITUTIONAL AMENDMENT.
JUNE 5, 2018, SPECIAL ELECTION
1 Measure
SENATE DISTRICT 29 - SPECIAL RECALL ELECTION